@@ -277,7 +277,7 @@ int dockwidget::heightForWidth( int w )
 
 void dockwidget::updateFont()
 {
-    kdDebug(12004) << "Update font: " << m_font.pixelSize() << endl;
+    //kdDebug(12004) << "Update font: " << m_font.pixelSize() << endl;
     m_lblTemp->setFont(m_font);
     m_lblWind->setFont(m_font);
     m_lblPres->setFont(m_font);
